@@ -710,10 +710,15 @@ void default_keybindings()
    }
    else {
       add_binding(BUTTON2, XCF_Text_Return);
+      add_binding(SHIFT | BUTTON1, XCF_Text_Return);
       add_binding(BUTTON2, XCF_Select);
+      add_binding(SHIFT | BUTTON1, XCF_Select);
       add_binding(HOLD | BUTTON2, XCF_SelectBox);
+      add_binding(SHIFT | HOLD | BUTTON1, XCF_Select);
       add_binding(BUTTON2, XCF_Finish_Element);
+      add_binding(SHIFT | BUTTON1, XCF_Finish_Element);
       add_binding(BUTTON2, XCF_Finish_Copy);
+      add_binding(SHIFT | BUTTON1, XCF_Finish_Copy);
       add_binding(BUTTON3, XCF_Cancel_Last);
       add_binding(BUTTON3, XCF_Cancel);
    }
